# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class TextRect(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'text': 'str',
        'page': 'int',
        'rect': 'Rectangle',
        'horizontal_alignment': 'HorizontalAlignment',
        'vertical_alignment': 'VerticalAlignment',
        'position': 'Position',
        'baseline_position': 'Position',
        'text_state': 'TextState'
    }

    attribute_map = {
        'text': 'Text',
        'page': 'Page',
        'rect': 'Rect',
        'horizontal_alignment': 'HorizontalAlignment',
        'vertical_alignment': 'VerticalAlignment',
        'position': 'Position',
        'baseline_position': 'BaselinePosition',
        'text_state': 'TextState'
    }

    def __init__(self, text=None, page=None, rect=None, horizontal_alignment=None, vertical_alignment=None, position=None, baseline_position=None, text_state=None):
        """
        TextRect - a model defined in Swagger
        """

        self._text = None
        self._page = None
        self._rect = None
        self._horizontal_alignment = None
        self._vertical_alignment = None
        self._position = None
        self._baseline_position = None
        self._text_state = None

        if text is not None:
          self.text = text
        if page is not None:
          self.page = page
        if rect is not None:
          self.rect = rect
        if horizontal_alignment is not None:
          self.horizontal_alignment = horizontal_alignment
        if vertical_alignment is not None:
          self.vertical_alignment = vertical_alignment
        if position is not None:
          self.position = position
        if baseline_position is not None:
          self.baseline_position = baseline_position
        if text_state is not None:
          self.text_state = text_state

    @property
    def text(self):
        """
        Gets the text of this TextRect.
        Text of the occurrence.

        :return: The text of this TextRect.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this TextRect.
        Text of the occurrence.

        :param text: The text of this TextRect.
        :type: str
        """

        self._text = text

    @property
    def page(self):
        """
        Gets the page of this TextRect.
        Page on which the occurrence is found.

        :return: The page of this TextRect.
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """
        Sets the page of this TextRect.
        Page on which the occurrence is found.

        :param page: The page of this TextRect.
        :type: int
        """

        self._page = page

    @property
    def rect(self):
        """
        Gets the rect of this TextRect.
        Rectangle of the occurrence.

        :return: The rect of this TextRect.
        :rtype: Rectangle
        """
        return self._rect

    @rect.setter
    def rect(self, rect):
        """
        Sets the rect of this TextRect.
        Rectangle of the occurrence.

        :param rect: The rect of this TextRect.
        :type: Rectangle
        """

        self._rect = rect

    @property
    def horizontal_alignment(self):
        """
        Gets the horizontal_alignment of this TextRect.
        Gets or sets a horizontal alignment of text fragment. 

        :return: The horizontal_alignment of this TextRect.
        :rtype: HorizontalAlignment
        """
        return self._horizontal_alignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, horizontal_alignment):
        """
        Sets the horizontal_alignment of this TextRect.
        Gets or sets a horizontal alignment of text fragment. 

        :param horizontal_alignment: The horizontal_alignment of this TextRect.
        :type: HorizontalAlignment
        """

        self._horizontal_alignment = horizontal_alignment

    @property
    def vertical_alignment(self):
        """
        Gets the vertical_alignment of this TextRect.
        Gets or sets a vertical alignment of text fragment. 

        :return: The vertical_alignment of this TextRect.
        :rtype: VerticalAlignment
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """
        Sets the vertical_alignment of this TextRect.
        Gets or sets a vertical alignment of text fragment. 

        :param vertical_alignment: The vertical_alignment of this TextRect.
        :type: VerticalAlignment
        """

        self._vertical_alignment = vertical_alignment

    @property
    def position(self):
        """
        Gets the position of this TextRect.
        Gets or sets text position for text, represented with TextRect object.

        :return: The position of this TextRect.
        :rtype: Position
        """
        return self._position

    @position.setter
    def position(self, position):
        """
        Sets the position of this TextRect.
        Gets or sets text position for text, represented with TextRect object.

        :param position: The position of this TextRect.
        :type: Position
        """

        self._position = position

    @property
    def baseline_position(self):
        """
        Gets the baseline_position of this TextRect.
        Gets text position for text, represented with TextRect object. The YIndent of the Position structure represents baseline coordinate of the text fragment.

        :return: The baseline_position of this TextRect.
        :rtype: Position
        """
        return self._baseline_position

    @baseline_position.setter
    def baseline_position(self, baseline_position):
        """
        Sets the baseline_position of this TextRect.
        Gets text position for text, represented with TextRect object. The YIndent of the Position structure represents baseline coordinate of the text fragment.

        :param baseline_position: The baseline_position of this TextRect.
        :type: Position
        """

        self._baseline_position = baseline_position

    @property
    def text_state(self):
        """
        Gets the text_state of this TextRect.
        Gets or sets text state for the text that TextRect object represents.

        :return: The text_state of this TextRect.
        :rtype: TextState
        """
        return self._text_state

    @text_state.setter
    def text_state(self, text_state):
        """
        Sets the text_state of this TextRect.
        Gets or sets text state for the text that TextRect object represents.

        :param text_state: The text_state of this TextRect.
        :type: TextState
        """

        self._text_state = text_state

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TextRect):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from configuration import *
file_name = 'PdfWithAnnotations.pdf'
uploadFile(file_name)

response_annotations = pdf_api.get_document_highlight_annotations(
    file_name, folder=temp_folder)
annotation_id = response_annotations.annotations.list[0].id

response = pdf_api.get_highlight_annotation(
    file_name, annotation_id, folder=temp_folder)

pprint(response)



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class Attachment(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'list[Link]',
        'description': 'str',
        'mime_type': 'str',
        'name': 'str',
        'creation_date': 'str',
        'modification_date': 'str',
        'size': 'int',
        'check_sum': 'str'
    }

    attribute_map = {
        'links': 'Links',
        'description': 'Description',
        'mime_type': 'MimeType',
        'name': 'Name',
        'creation_date': 'CreationDate',
        'modification_date': 'ModificationDate',
        'size': 'Size',
        'check_sum': 'CheckSum'
    }

    def __init__(self, links=None, description=None, mime_type=None, name=None, creation_date=None, modification_date=None, size=None, check_sum=None):
        """
        Attachment - a model defined in Swagger
        """

        self._links = None
        self._description = None
        self._mime_type = None
        self._name = None
        self._creation_date = None
        self._modification_date = None
        self._size = None
        self._check_sum = None

        if links is not None:
          self.links = links
        if description is not None:
          self.description = description
        if mime_type is not None:
          self.mime_type = mime_type
        if name is not None:
          self.name = name
        if creation_date is not None:
          self.creation_date = creation_date
        if modification_date is not None:
          self.modification_date = modification_date
        self.size = size
        if check_sum is not None:
          self.check_sum = check_sum

    @property
    def links(self):
        """
        Gets the links of this Attachment.
        Link to the document.

        :return: The links of this Attachment.
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this Attachment.
        Link to the document.

        :param links: The links of this Attachment.
        :type: list[Link]
        """

        self._links = links

    @property
    def description(self):
        """
        Gets the description of this Attachment.
        Gets text associated with the attachment. 

        :return: The description of this Attachment.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Attachment.
        Gets text associated with the attachment. 

        :param description: The description of this Attachment.
        :type: str
        """

        self._description = description

    @property
    def mime_type(self):
        """
        Gets the mime_type of this Attachment.
        Gets subtype of the attachment file.

        :return: The mime_type of this Attachment.
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """
        Sets the mime_type of this Attachment.
        Gets subtype of the attachment file.

        :param mime_type: The mime_type of this Attachment.
        :type: str
        """

        self._mime_type = mime_type

    @property
    def name(self):
        """
        Gets the name of this Attachment.
        Gets the name of the attachment. 

        :return: The name of this Attachment.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Attachment.
        Gets the name of the attachment. 

        :param name: The name of this Attachment.
        :type: str
        """

        self._name = name

    @property
    def creation_date(self):
        """
        Gets the creation_date of this Attachment.
        The date and time when the embedded file was created.

        :return: The creation_date of this Attachment.
        :rtype: str
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """
        Sets the creation_date of this Attachment.
        The date and time when the embedded file was created.

        :param creation_date: The creation_date of this Attachment.
        :type: str
        """

        self._creation_date = creation_date

    @property
    def modification_date(self):
        """
        Gets the modification_date of this Attachment.
        The date and time when the embedded file was last modified.

        :return: The modification_date of this Attachment.
        :rtype: str
        """
        return self._modification_date

    @modification_date.setter
    def modification_date(self, modification_date):
        """
        Sets the modification_date of this Attachment.
        The date and time when the embedded file was last modified.

        :param modification_date: The modification_date of this Attachment.
        :type: str
        """

        self._modification_date = modification_date

    @property
    def size(self):
        """
        Gets the size of this Attachment.
        The size of the uncompressed embedded file, in bytes.

        :return: The size of this Attachment.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this Attachment.
        The size of the uncompressed embedded file, in bytes.

        :param size: The size of this Attachment.
        :type: int
        """
        if size is None:
            raise ValueError("Invalid value for `size`, must not be `None`")

        self._size = size

    @property
    def check_sum(self):
        """
        Gets the check_sum of this Attachment.
        A 16-byte string that is the checksum of the bytes of the uncompressed embedded file.  The checksum is calculated by applying the standard MD5 message-digest algorithm  to the bytes of the embedded file stream.

        :return: The check_sum of this Attachment.
        :rtype: str
        """
        return self._check_sum

    @check_sum.setter
    def check_sum(self, check_sum):
        """
        Sets the check_sum of this Attachment.
        A 16-byte string that is the checksum of the bytes of the uncompressed embedded file.  The checksum is calculated by applying the standard MD5 message-digest algorithm  to the bytes of the embedded file stream.

        :param check_sum: The check_sum of this Attachment.
        :type: str
        """

        self._check_sum = check_sum

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Attachment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class LineAnnotation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'list[Link]',
        'color': 'Color',
        'contents': 'str',
        'modified': 'str',
        'id': 'str',
        'flags': 'list[AnnotationFlags]',
        'name': 'str',
        'rect': 'Rectangle',
        'page_index': 'int',
        'z_index': 'int',
        'horizontal_alignment': 'HorizontalAlignment',
        'vertical_alignment': 'VerticalAlignment',
        'creation_date': 'str',
        'subject': 'str',
        'title': 'str',
        'rich_text': 'str',
        'starting': 'Point',
        'starting_style': 'LineEnding',
        'ending': 'Point',
        'ending_style': 'LineEnding',
        'interior_color': 'Color',
        'leader_line': 'float',
        'leader_line_extension': 'float',
        'leader_line_offset': 'float',
        'show_caption': 'bool',
        'caption_offset': 'Point',
        'caption_position': 'CaptionPosition',
        'intent': 'LineIntent'
    }

    attribute_map = {
        'links': 'Links',
        'color': 'Color',
        'contents': 'Contents',
        'modified': 'Modified',
        'id': 'Id',
        'flags': 'Flags',
        'name': 'Name',
        'rect': 'Rect',
        'page_index': 'PageIndex',
        'z_index': 'ZIndex',
        'horizontal_alignment': 'HorizontalAlignment',
        'vertical_alignment': 'VerticalAlignment',
        'creation_date': 'CreationDate',
        'subject': 'Subject',
        'title': 'Title',
        'rich_text': 'RichText',
        'starting': 'Starting',
        'starting_style': 'StartingStyle',
        'ending': 'Ending',
        'ending_style': 'EndingStyle',
        'interior_color': 'InteriorColor',
        'leader_line': 'LeaderLine',
        'leader_line_extension': 'LeaderLineExtension',
        'leader_line_offset': 'LeaderLineOffset',
        'show_caption': 'ShowCaption',
        'caption_offset': 'CaptionOffset',
        'caption_position': 'CaptionPosition',
        'intent': 'Intent'
    }

    def __init__(self, links=None, color=None, contents=None, modified=None, id=None, flags=None, name=None, rect=None, page_index=None, z_index=None, horizontal_alignment=None, vertical_alignment=None, creation_date=None, subject=None, title=None, rich_text=None, starting=None, starting_style=None, ending=None, ending_style=None, interior_color=None, leader_line=None, leader_line_extension=None, leader_line_offset=None, show_caption=None, caption_offset=None, caption_position=None, intent=None):
        """
        LineAnnotation - a model defined in Swagger
        """

        self._links = None
        self._color = None
        self._contents = None
        self._modified = None
        self._id = None
        self._flags = None
        self._name = None
        self._rect = None
        self._page_index = None
        self._z_index = None
        self._horizontal_alignment = None
        self._vertical_alignment = None
        self._creation_date = None
        self._subject = None
        self._title = None
        self._rich_text = None
        self._starting = None
        self._starting_style = None
        self._ending = None
        self._ending_style = None
        self._interior_color = None
        self._leader_line = None
        self._leader_line_extension = None
        self._leader_line_offset = None
        self._show_caption = None
        self._caption_offset = None
        self._caption_position = None
        self._intent = None

        if links is not None:
          self.links = links
        if color is not None:
          self.color = color
        if contents is not None:
          self.contents = contents
        if modified is not None:
          self.modified = modified
        if id is not None:
          self.id = id
        if flags is not None:
          self.flags = flags
        if name is not None:
          self.name = name
        self.rect = rect
        if page_index is not None:
          self.page_index = page_index
        if z_index is not None:
          self.z_index = z_index
        if horizontal_alignment is not None:
          self.horizontal_alignment = horizontal_alignment
        if vertical_alignment is not None:
          self.vertical_alignment = vertical_alignment
        if creation_date is not None:
          self.creation_date = creation_date
        if subject is not None:
          self.subject = subject
        if title is not None:
          self.title = title
        if rich_text is not None:
          self.rich_text = rich_text
        self.starting = starting
        if starting_style is not None:
          self.starting_style = starting_style
        self.ending = ending
        if ending_style is not None:
          self.ending_style = ending_style
        if interior_color is not None:
          self.interior_color = interior_color
        if leader_line is not None:
          self.leader_line = leader_line
        if leader_line_extension is not None:
          self.leader_line_extension = leader_line_extension
        if leader_line_offset is not None:
          self.leader_line_offset = leader_line_offset
        if show_caption is not None:
          self.show_caption = show_caption
        if caption_offset is not None:
          self.caption_offset = caption_offset
        if caption_position is not None:
          self.caption_position = caption_position
        if intent is not None:
          self.intent = intent

    @property
    def links(self):
        """
        Gets the links of this LineAnnotation.
        Link to the document.

        :return: The links of this LineAnnotation.
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this LineAnnotation.
        Link to the document.

        :param links: The links of this LineAnnotation.
        :type: list[Link]
        """

        self._links = links

    @property
    def color(self):
        """
        Gets the color of this LineAnnotation.
        Color of the annotation.

        :return: The color of this LineAnnotation.
        :rtype: Color
        """
        return self._color

    @color.setter
    def color(self, color):
        """
        Sets the color of this LineAnnotation.
        Color of the annotation.

        :param color: The color of this LineAnnotation.
        :type: Color
        """

        self._color = color

    @property
    def contents(self):
        """
        Gets the contents of this LineAnnotation.
        Get the annotation content.

        :return: The contents of this LineAnnotation.
        :rtype: str
        """
        return self._contents

    @contents.setter
    def contents(self, contents):
        """
        Sets the contents of this LineAnnotation.
        Get the annotation content.

        :param contents: The contents of this LineAnnotation.
        :type: str
        """

        self._contents = contents

    @property
    def modified(self):
        """
        Gets the modified of this LineAnnotation.
        The date and time when the annotation was last modified.

        :return: The modified of this LineAnnotation.
        :rtype: str
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """
        Sets the modified of this LineAnnotation.
        The date and time when the annotation was last modified.

        :param modified: The modified of this LineAnnotation.
        :type: str
        """

        self._modified = modified

    @property
    def id(self):
        """
        Gets the id of this LineAnnotation.
        Gets ID of the annotation.

        :return: The id of this LineAnnotation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LineAnnotation.
        Gets ID of the annotation.

        :param id: The id of this LineAnnotation.
        :type: str
        """

        self._id = id

    @property
    def flags(self):
        """
        Gets the flags of this LineAnnotation.
        Gets Flags of the annotation.

        :return: The flags of this LineAnnotation.
        :rtype: list[AnnotationFlags]
        """
        return self._flags

    @flags.setter
    def flags(self, flags):
        """
        Sets the flags of this LineAnnotation.
        Gets Flags of the annotation.

        :param flags: The flags of this LineAnnotation.
        :type: list[AnnotationFlags]
        """

        self._flags = flags

    @property
    def name(self):
        """
        Gets the name of this LineAnnotation.
        Gets Name of the annotation.

        :return: The name of this LineAnnotation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LineAnnotation.
        Gets Name of the annotation.

        :param name: The name of this LineAnnotation.
        :type: str
        """

        self._name = name

    @property
    def rect(self):
        """
        Gets the rect of this LineAnnotation.
        Gets Rect of the annotation.

        :return: The rect of this LineAnnotation.
        :rtype: Rectangle
        """
        return self._rect

    @rect.setter
    def rect(self, rect):
        """
        Sets the rect of this LineAnnotation.
        Gets Rect of the annotation.

        :param rect: The rect of this LineAnnotation.
        :type: Rectangle
        """
        if rect is None:
            raise ValueError("Invalid value for `rect`, must not be `None`")

        self._rect = rect

    @property
    def page_index(self):
        """
        Gets the page_index of this LineAnnotation.
        Gets PageIndex of the annotation.

        :return: The page_index of this LineAnnotation.
        :rtype: int
        """
        return self._page_index

    @page_index.setter
    def page_index(self, page_index):
        """
        Sets the page_index of this LineAnnotation.
        Gets PageIndex of the annotation.

        :param page_index: The page_index of this LineAnnotation.
        :type: int
        """

        self._page_index = page_index

    @property
    def z_index(self):
        """
        Gets the z_index of this LineAnnotation.
        Gets ZIndex of the annotation.

        :return: The z_index of this LineAnnotation.
        :rtype: int
        """
        return self._z_index

    @z_index.setter
    def z_index(self, z_index):
        """
        Sets the z_index of this LineAnnotation.
        Gets ZIndex of the annotation.

        :param z_index: The z_index of this LineAnnotation.
        :type: int
        """

        self._z_index = z_index

    @property
    def horizontal_alignment(self):
        """
        Gets the horizontal_alignment of this LineAnnotation.
        Gets HorizontalAlignment of the annotation.

        :return: The horizontal_alignment of this LineAnnotation.
        :rtype: HorizontalAlignment
        """
        return self._horizontal_alignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, horizontal_alignment):
        """
        Sets the horizontal_alignment of this LineAnnotation.
        Gets HorizontalAlignment of the annotation.

        :param horizontal_alignment: The horizontal_alignment of this LineAnnotation.
        :type: HorizontalAlignment
        """

        self._horizontal_alignment = horizontal_alignment

    @property
    def vertical_alignment(self):
        """
        Gets the vertical_alignment of this LineAnnotation.
        Gets VerticalAlignment of the annotation.

        :return: The vertical_alignment of this LineAnnotation.
        :rtype: VerticalAlignment
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """
        Sets the vertical_alignment of this LineAnnotation.
        Gets VerticalAlignment of the annotation.

        :param vertical_alignment: The vertical_alignment of this LineAnnotation.
        :type: VerticalAlignment
        """

        self._vertical_alignment = vertical_alignment

    @property
    def creation_date(self):
        """
        Gets the creation_date of this LineAnnotation.
        The date and time when the annotation was created.

        :return: The creation_date of this LineAnnotation.
        :rtype: str
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """
        Sets the creation_date of this LineAnnotation.
        The date and time when the annotation was created.

        :param creation_date: The creation_date of this LineAnnotation.
        :type: str
        """

        self._creation_date = creation_date

    @property
    def subject(self):
        """
        Gets the subject of this LineAnnotation.
        Get the annotation subject.

        :return: The subject of this LineAnnotation.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this LineAnnotation.
        Get the annotation subject.

        :param subject: The subject of this LineAnnotation.
        :type: str
        """

        self._subject = subject

    @property
    def title(self):
        """
        Gets the title of this LineAnnotation.
        Get the annotation title.

        :return: The title of this LineAnnotation.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this LineAnnotation.
        Get the annotation title.

        :param title: The title of this LineAnnotation.
        :type: str
        """

        self._title = title

    @property
    def rich_text(self):
        """
        Gets the rich_text of this LineAnnotation.
        Get the annotation RichText.

        :return: The rich_text of this LineAnnotation.
        :rtype: str
        """
        return self._rich_text

    @rich_text.setter
    def rich_text(self, rich_text):
        """
        Sets the rich_text of this LineAnnotation.
        Get the annotation RichText.

        :param rich_text: The rich_text of this LineAnnotation.
        :type: str
        """

        self._rich_text = rich_text

    @property
    def starting(self):
        """
        Gets the starting of this LineAnnotation.
        Gets or sets starting point of line.

        :return: The starting of this LineAnnotation.
        :rtype: Point
        """
        return self._starting

    @starting.setter
    def starting(self, starting):
        """
        Sets the starting of this LineAnnotation.
        Gets or sets starting point of line.

        :param starting: The starting of this LineAnnotation.
        :type: Point
        """
        if starting is None:
            raise ValueError("Invalid value for `starting`, must not be `None`")

        self._starting = starting

    @property
    def starting_style(self):
        """
        Gets the starting_style of this LineAnnotation.
        Gets or sets line ending style for line starting point.

        :return: The starting_style of this LineAnnotation.
        :rtype: LineEnding
        """
        return self._starting_style

    @starting_style.setter
    def starting_style(self, starting_style):
        """
        Sets the starting_style of this LineAnnotation.
        Gets or sets line ending style for line starting point.

        :param starting_style: The starting_style of this LineAnnotation.
        :type: LineEnding
        """

        self._starting_style = starting_style

    @property
    def ending(self):
        """
        Gets the ending of this LineAnnotation.
        Gets or sets ending point of line.

        :return: The ending of this LineAnnotation.
        :rtype: Point
        """
        return self._ending

    @ending.setter
    def ending(self, ending):
        """
        Sets the ending of this LineAnnotation.
        Gets or sets ending point of line.

        :param ending: The ending of this LineAnnotation.
        :type: Point
        """
        if ending is None:
            raise ValueError("Invalid value for `ending`, must not be `None`")

        self._ending = ending

    @property
    def ending_style(self):
        """
        Gets the ending_style of this LineAnnotation.
        Gets or sets ending style for end point of line.

        :return: The ending_style of this LineAnnotation.
        :rtype: LineEnding
        """
        return self._ending_style

    @ending_style.setter
    def ending_style(self, ending_style):
        """
        Sets the ending_style of this LineAnnotation.
        Gets or sets ending style for end point of line.

        :param ending_style: The ending_style of this LineAnnotation.
        :type: LineEnding
        """

        self._ending_style = ending_style

    @property
    def interior_color(self):
        """
        Gets the interior_color of this LineAnnotation.
        Gets or sets interior color of the annotation.

        :return: The interior_color of this LineAnnotation.
        :rtype: Color
        """
        return self._interior_color

    @interior_color.setter
    def interior_color(self, interior_color):
        """
        Sets the interior_color of this LineAnnotation.
        Gets or sets interior color of the annotation.

        :param interior_color: The interior_color of this LineAnnotation.
        :type: Color
        """

        self._interior_color = interior_color

    @property
    def leader_line(self):
        """
        Gets the leader_line of this LineAnnotation.
        Gets or sets leader line length.

        :return: The leader_line of this LineAnnotation.
        :rtype: float
        """
        return self._leader_line

    @leader_line.setter
    def leader_line(self, leader_line):
        """
        Sets the leader_line of this LineAnnotation.
        Gets or sets leader line length.

        :param leader_line: The leader_line of this LineAnnotation.
        :type: float
        """

        self._leader_line = leader_line

    @property
    def leader_line_extension(self):
        """
        Gets the leader_line_extension of this LineAnnotation.
        Gets or sets length of leader line extension.

        :return: The leader_line_extension of this LineAnnotation.
        :rtype: float
        """
        return self._leader_line_extension

    @leader_line_extension.setter
    def leader_line_extension(self, leader_line_extension):
        """
        Sets the leader_line_extension of this LineAnnotation.
        Gets or sets length of leader line extension.

        :param leader_line_extension: The leader_line_extension of this LineAnnotation.
        :type: float
        """

        self._leader_line_extension = leader_line_extension

    @property
    def leader_line_offset(self):
        """
        Gets the leader_line_offset of this LineAnnotation.
        Gets or sets leader line offset.

        :return: The leader_line_offset of this LineAnnotation.
        :rtype: float
        """
        return self._leader_line_offset

    @leader_line_offset.setter
    def leader_line_offset(self, leader_line_offset):
        """
        Sets the leader_line_offset of this LineAnnotation.
        Gets or sets leader line offset.

        :param leader_line_offset: The leader_line_offset of this LineAnnotation.
        :type: float
        """

        self._leader_line_offset = leader_line_offset

    @property
    def show_caption(self):
        """
        Gets the show_caption of this LineAnnotation.
        Gets or sets boolean flag which determinies is contents must be shown as caption.

        :return: The show_caption of this LineAnnotation.
        :rtype: bool
        """
        return self._show_caption

    @show_caption.setter
    def show_caption(self, show_caption):
        """
        Sets the show_caption of this LineAnnotation.
        Gets or sets boolean flag which determinies is contents must be shown as caption.

        :param show_caption: The show_caption of this LineAnnotation.
        :type: bool
        """

        self._show_caption = show_caption

    @property
    def caption_offset(self):
        """
        Gets the caption_offset of this LineAnnotation.
        Gets or sets caption text offset from its normal position.

        :return: The caption_offset of this LineAnnotation.
        :rtype: Point
        """
        return self._caption_offset

    @caption_offset.setter
    def caption_offset(self, caption_offset):
        """
        Sets the caption_offset of this LineAnnotation.
        Gets or sets caption text offset from its normal position.

        :param caption_offset: The caption_offset of this LineAnnotation.
        :type: Point
        """

        self._caption_offset = caption_offset

    @property
    def caption_position(self):
        """
        Gets the caption_position of this LineAnnotation.
        Gets or sets annotation caption position.

        :return: The caption_position of this LineAnnotation.
        :rtype: CaptionPosition
        """
        return self._caption_position

    @caption_position.setter
    def caption_position(self, caption_position):
        """
        Sets the caption_position of this LineAnnotation.
        Gets or sets annotation caption position.

        :param caption_position: The caption_position of this LineAnnotation.
        :type: CaptionPosition
        """

        self._caption_position = caption_position

    @property
    def intent(self):
        """
        Gets the intent of this LineAnnotation.
        Gets or sets the intent of the line annotation.

        :return: The intent of this LineAnnotation.
        :rtype: LineIntent
        """
        return self._intent

    @intent.setter
    def intent(self, intent):
        """
        Sets the intent of this LineAnnotation.
        Gets or sets the intent of the line annotation.

        :param intent: The intent of this LineAnnotation.
        :type: LineIntent
        """

        self._intent = intent

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, LineAnnotation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from configuration import *
file_name = '4pages.pdf'
uploadFile(file_name)

opts = {
    "folder": temp_folder
}

response = pdf_api.get_pdf_in_storage_to_pdf_a(
    file_name, asposepdfcloud.models.PdfAType.PDFA1A, **opts)

pprint(response)



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class TextReplaceListRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'text_replaces': 'list[TextReplace]',
        'default_font': 'str',
        'start_index': 'int',
        'count_replace': 'int'
    }

    attribute_map = {
        'text_replaces': 'TextReplaces',
        'default_font': 'DefaultFont',
        'start_index': 'StartIndex',
        'count_replace': 'CountReplace'
    }

    def __init__(self, text_replaces=None, default_font=None, start_index=None, count_replace=None):
        """
        TextReplaceListRequest - a model defined in Swagger
        """

        self._text_replaces = None
        self._default_font = None
        self._start_index = None
        self._count_replace = None

        self.text_replaces = text_replaces
        if default_font is not None:
          self.default_font = default_font
        if start_index is not None:
          self.start_index = start_index
        if count_replace is not None:
          self.count_replace = count_replace

    @property
    def text_replaces(self):
        """
        Gets the text_replaces of this TextReplaceListRequest.
        A list of text replacement settings.

        :return: The text_replaces of this TextReplaceListRequest.
        :rtype: list[TextReplace]
        """
        return self._text_replaces

    @text_replaces.setter
    def text_replaces(self, text_replaces):
        """
        Sets the text_replaces of this TextReplaceListRequest.
        A list of text replacement settings.

        :param text_replaces: The text_replaces of this TextReplaceListRequest.
        :type: list[TextReplace]
        """
        if text_replaces is None:
            raise ValueError("Invalid value for `text_replaces`, must not be `None`")

        self._text_replaces = text_replaces

    @property
    def default_font(self):
        """
        Gets the default_font of this TextReplaceListRequest.
        Name of font to use if requested font is not embedded into document.

        :return: The default_font of this TextReplaceListRequest.
        :rtype: str
        """
        return self._default_font

    @default_font.setter
    def default_font(self, default_font):
        """
        Sets the default_font of this TextReplaceListRequest.
        Name of font to use if requested font is not embedded into document.

        :param default_font: The default_font of this TextReplaceListRequest.
        :type: str
        """

        self._default_font = default_font

    @property
    def start_index(self):
        """
        Gets the start_index of this TextReplaceListRequest.
        The index of first match to be replaced.

        :return: The start_index of this TextReplaceListRequest.
        :rtype: int
        """
        return self._start_index

    @start_index.setter
    def start_index(self, start_index):
        """
        Sets the start_index of this TextReplaceListRequest.
        The index of first match to be replaced.

        :param start_index: The start_index of this TextReplaceListRequest.
        :type: int
        """

        self._start_index = start_index

    @property
    def count_replace(self):
        """
        Gets the count_replace of this TextReplaceListRequest.
        The number of matches to be replaced.

        :return: The count_replace of this TextReplaceListRequest.
        :rtype: int
        """
        return self._count_replace

    @count_replace.setter
    def count_replace(self, count_replace):
        """
        Sets the count_replace of this TextReplaceListRequest.
        The number of matches to be replaced.

        :param count_replace: The count_replace of this TextReplaceListRequest.
        :type: int
        """

        self._count_replace = count_replace

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TextReplaceListRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class Stamp(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'StampType',
        'background': 'bool',
        'bottom_margin': 'float',
        'horizontal_alignment': 'HorizontalAlignment',
        'left_margin': 'float',
        'opacity': 'float',
        'right_margin': 'float',
        'rotate': 'Rotation',
        'rotate_angle': 'float',
        'top_margin': 'float',
        'vertical_alignment': 'VerticalAlignment',
        'x_indent': 'float',
        'y_indent': 'float',
        'zoom': 'float',
        'text_alignment': 'HorizontalAlignment',
        'value': 'str',
        'text_state': 'TextState',
        'file_name': 'str',
        'width': 'float',
        'height': 'float',
        'page_index': 'int',
        'starting_number': 'int'
    }

    attribute_map = {
        'type': 'Type',
        'background': 'Background',
        'bottom_margin': 'BottomMargin',
        'horizontal_alignment': 'HorizontalAlignment',
        'left_margin': 'LeftMargin',
        'opacity': 'Opacity',
        'right_margin': 'RightMargin',
        'rotate': 'Rotate',
        'rotate_angle': 'RotateAngle',
        'top_margin': 'TopMargin',
        'vertical_alignment': 'VerticalAlignment',
        'x_indent': 'XIndent',
        'y_indent': 'YIndent',
        'zoom': 'Zoom',
        'text_alignment': 'TextAlignment',
        'value': 'Value',
        'text_state': 'TextState',
        'file_name': 'FileName',
        'width': 'Width',
        'height': 'Height',
        'page_index': 'PageIndex',
        'starting_number': 'StartingNumber'
    }

    def __init__(self, type=None, background=None, bottom_margin=None, horizontal_alignment=None, left_margin=None, opacity=None, right_margin=None, rotate=None, rotate_angle=None, top_margin=None, vertical_alignment=None, x_indent=None, y_indent=None, zoom=None, text_alignment=None, value=None, text_state=None, file_name=None, width=None, height=None, page_index=None, starting_number=None):
        """
        Stamp - a model defined in Swagger
        """

        self._type = None
        self._background = None
        self._bottom_margin = None
        self._horizontal_alignment = None
        self._left_margin = None
        self._opacity = None
        self._right_margin = None
        self._rotate = None
        self._rotate_angle = None
        self._top_margin = None
        self._vertical_alignment = None
        self._x_indent = None
        self._y_indent = None
        self._zoom = None
        self._text_alignment = None
        self._value = None
        self._text_state = None
        self._file_name = None
        self._width = None
        self._height = None
        self._page_index = None
        self._starting_number = None

        self.type = type
        if background is not None:
          self.background = background
        if bottom_margin is not None:
          self.bottom_margin = bottom_margin
        if horizontal_alignment is not None:
          self.horizontal_alignment = horizontal_alignment
        if left_margin is not None:
          self.left_margin = left_margin
        if opacity is not None:
          self.opacity = opacity
        if right_margin is not None:
          self.right_margin = right_margin
        if rotate is not None:
          self.rotate = rotate
        if rotate_angle is not None:
          self.rotate_angle = rotate_angle
        if top_margin is not None:
          self.top_margin = top_margin
        if vertical_alignment is not None:
          self.vertical_alignment = vertical_alignment
        if x_indent is not None:
          self.x_indent = x_indent
        if y_indent is not None:
          self.y_indent = y_indent
        if zoom is not None:
          self.zoom = zoom
        if text_alignment is not None:
          self.text_alignment = text_alignment
        if value is not None:
          self.value = value
        if text_state is not None:
          self.text_state = text_state
        if file_name is not None:
          self.file_name = file_name
        if width is not None:
          self.width = width
        if height is not None:
          self.height = height
        if page_index is not None:
          self.page_index = page_index
        if starting_number is not None:
          self.starting_number = starting_number

    @property
    def type(self):
        """
        Gets the type of this Stamp.
        Gets the stamp type.

        :return: The type of this Stamp.
        :rtype: StampType
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Stamp.
        Gets the stamp type.

        :param type: The type of this Stamp.
        :type: StampType
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    @property
    def background(self):
        """
        Gets the background of this Stamp.
        Sets or gets a bool value that indicates the content is stamped as background. If the value is true, the stamp content is layed at the bottom. By defalt, the value is false, the stamp content is layed at the top.

        :return: The background of this Stamp.
        :rtype: bool
        """
        return self._background

    @background.setter
    def background(self, background):
        """
        Sets the background of this Stamp.
        Sets or gets a bool value that indicates the content is stamped as background. If the value is true, the stamp content is layed at the bottom. By defalt, the value is false, the stamp content is layed at the top.

        :param background: The background of this Stamp.
        :type: bool
        """

        self._background = background

    @property
    def bottom_margin(self):
        """
        Gets the bottom_margin of this Stamp.
        Gets or sets bottom margin of stamp.

        :return: The bottom_margin of this Stamp.
        :rtype: float
        """
        return self._bottom_margin

    @bottom_margin.setter
    def bottom_margin(self, bottom_margin):
        """
        Sets the bottom_margin of this Stamp.
        Gets or sets bottom margin of stamp.

        :param bottom_margin: The bottom_margin of this Stamp.
        :type: float
        """

        self._bottom_margin = bottom_margin

    @property
    def horizontal_alignment(self):
        """
        Gets the horizontal_alignment of this Stamp.
        Gets or sets Horizontal alignment of stamp on the page. 

        :return: The horizontal_alignment of this Stamp.
        :rtype: HorizontalAlignment
        """
        return self._horizontal_alignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, horizontal_alignment):
        """
        Sets the horizontal_alignment of this Stamp.
        Gets or sets Horizontal alignment of stamp on the page. 

        :param horizontal_alignment: The horizontal_alignment of this Stamp.
        :type: HorizontalAlignment
        """

        self._horizontal_alignment = horizontal_alignment

    @property
    def left_margin(self):
        """
        Gets the left_margin of this Stamp.
        Gets or sets left margin of stamp.

        :return: The left_margin of this Stamp.
        :rtype: float
        """
        return self._left_margin

    @left_margin.setter
    def left_margin(self, left_margin):
        """
        Sets the left_margin of this Stamp.
        Gets or sets left margin of stamp.

        :param left_margin: The left_margin of this Stamp.
        :type: float
        """

        self._left_margin = left_margin

    @property
    def opacity(self):
        """
        Gets the opacity of this Stamp.
        Gets or sets a value to indicate the stamp opacity. The value is from 0.0 to 1.0. By default the value is 1.0.

        :return: The opacity of this Stamp.
        :rtype: float
        """
        return self._opacity

    @opacity.setter
    def opacity(self, opacity):
        """
        Sets the opacity of this Stamp.
        Gets or sets a value to indicate the stamp opacity. The value is from 0.0 to 1.0. By default the value is 1.0.

        :param opacity: The opacity of this Stamp.
        :type: float
        """

        self._opacity = opacity

    @property
    def right_margin(self):
        """
        Gets the right_margin of this Stamp.
        Gets or sets right margin of stamp.

        :return: The right_margin of this Stamp.
        :rtype: float
        """
        return self._right_margin

    @right_margin.setter
    def right_margin(self, right_margin):
        """
        Sets the right_margin of this Stamp.
        Gets or sets right margin of stamp.

        :param right_margin: The right_margin of this Stamp.
        :type: float
        """

        self._right_margin = right_margin

    @property
    def rotate(self):
        """
        Gets the rotate of this Stamp.
        Sets or gets the rotation of stamp content according Rotation values. Note. This property is for set angles which are multiples of 90 degrees (0, 90, 180, 270 degrees). To set arbitrary angle use RotateAngle property.  If angle set by ArbitraryAngle is not multiple of 90 then Rotate property returns Rotation.None.

        :return: The rotate of this Stamp.
        :rtype: Rotation
        """
        return self._rotate

    @rotate.setter
    def rotate(self, rotate):
        """
        Sets the rotate of this Stamp.
        Sets or gets the rotation of stamp content according Rotation values. Note. This property is for set angles which are multiples of 90 degrees (0, 90, 180, 270 degrees). To set arbitrary angle use RotateAngle property.  If angle set by ArbitraryAngle is not multiple of 90 then Rotate property returns Rotation.None.

        :param rotate: The rotate of this Stamp.
        :type: Rotation
        """

        self._rotate = rotate

    @property
    def rotate_angle(self):
        """
        Gets the rotate_angle of this Stamp.
        Gets or sets rotate angle of stamp in degrees. This property allows to set arbitrary rotate angle. 

        :return: The rotate_angle of this Stamp.
        :rtype: float
        """
        return self._rotate_angle

    @rotate_angle.setter
    def rotate_angle(self, rotate_angle):
        """
        Sets the rotate_angle of this Stamp.
        Gets or sets rotate angle of stamp in degrees. This property allows to set arbitrary rotate angle. 

        :param rotate_angle: The rotate_angle of this Stamp.
        :type: float
        """

        self._rotate_angle = rotate_angle

    @property
    def top_margin(self):
        """
        Gets the top_margin of this Stamp.
        Gets or sets top margin of stamp.

        :return: The top_margin of this Stamp.
        :rtype: float
        """
        return self._top_margin

    @top_margin.setter
    def top_margin(self, top_margin):
        """
        Sets the top_margin of this Stamp.
        Gets or sets top margin of stamp.

        :param top_margin: The top_margin of this Stamp.
        :type: float
        """

        self._top_margin = top_margin

    @property
    def vertical_alignment(self):
        """
        Gets the vertical_alignment of this Stamp.
        Gets or sets vertical alignment of stamp on page.

        :return: The vertical_alignment of this Stamp.
        :rtype: VerticalAlignment
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """
        Sets the vertical_alignment of this Stamp.
        Gets or sets vertical alignment of stamp on page.

        :param vertical_alignment: The vertical_alignment of this Stamp.
        :type: VerticalAlignment
        """

        self._vertical_alignment = vertical_alignment

    @property
    def x_indent(self):
        """
        Gets the x_indent of this Stamp.
        Horizontal stamp coordinate, starting from the left.

        :return: The x_indent of this Stamp.
        :rtype: float
        """
        return self._x_indent

    @x_indent.setter
    def x_indent(self, x_indent):
        """
        Sets the x_indent of this Stamp.
        Horizontal stamp coordinate, starting from the left.

        :param x_indent: The x_indent of this Stamp.
        :type: float
        """

        self._x_indent = x_indent

    @property
    def y_indent(self):
        """
        Gets the y_indent of this Stamp.
        Vertical stamp coordinate, starting from the bottom.

        :return: The y_indent of this Stamp.
        :rtype: float
        """
        return self._y_indent

    @y_indent.setter
    def y_indent(self, y_indent):
        """
        Sets the y_indent of this Stamp.
        Vertical stamp coordinate, starting from the bottom.

        :param y_indent: The y_indent of this Stamp.
        :type: float
        """

        self._y_indent = y_indent

    @property
    def zoom(self):
        """
        Gets the zoom of this Stamp.
        Zooming factor of the stamp. Allows to scale stamp.

        :return: The zoom of this Stamp.
        :rtype: float
        """
        return self._zoom

    @zoom.setter
    def zoom(self, zoom):
        """
        Sets the zoom of this Stamp.
        Zooming factor of the stamp. Allows to scale stamp.

        :param zoom: The zoom of this Stamp.
        :type: float
        """

        self._zoom = zoom

    @property
    def text_alignment(self):
        """
        Gets the text_alignment of this Stamp.
        Alignment of the text inside the stamp.

        :return: The text_alignment of this Stamp.
        :rtype: HorizontalAlignment
        """
        return self._text_alignment

    @text_alignment.setter
    def text_alignment(self, text_alignment):
        """
        Sets the text_alignment of this Stamp.
        Alignment of the text inside the stamp.

        :param text_alignment: The text_alignment of this Stamp.
        :type: HorizontalAlignment
        """

        self._text_alignment = text_alignment

    @property
    def value(self):
        """
        Gets the value of this Stamp.
        Gets or sets string value which is used as stamp on the page.

        :return: The value of this Stamp.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this Stamp.
        Gets or sets string value which is used as stamp on the page.

        :param value: The value of this Stamp.
        :type: str
        """

        self._value = value

    @property
    def text_state(self):
        """
        Gets the text_state of this Stamp.
        Gets text properties of the stamp. See TextState for details.

        :return: The text_state of this Stamp.
        :rtype: TextState
        """
        return self._text_state

    @text_state.setter
    def text_state(self, text_state):
        """
        Sets the text_state of this Stamp.
        Gets text properties of the stamp. See TextState for details.

        :param text_state: The text_state of this Stamp.
        :type: TextState
        """

        self._text_state = text_state

    @property
    def file_name(self):
        """
        Gets the file_name of this Stamp.
        Gets or sets the file name.

        :return: The file_name of this Stamp.
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """
        Sets the file_name of this Stamp.
        Gets or sets the file name.

        :param file_name: The file_name of this Stamp.
        :type: str
        """

        self._file_name = file_name

    @property
    def width(self):
        """
        Gets the width of this Stamp.
        Gets or sets image width. Setting this property allos to scal image horizontally.

        :return: The width of this Stamp.
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """
        Sets the width of this Stamp.
        Gets or sets image width. Setting this property allos to scal image horizontally.

        :param width: The width of this Stamp.
        :type: float
        """

        self._width = width

    @property
    def height(self):
        """
        Gets the height of this Stamp.
        Gets or sets image height. Setting this image allows to scale image vertically.

        :return: The height of this Stamp.
        :rtype: float
        """
        return self._height

    @height.setter
    def height(self, height):
        """
        Sets the height of this Stamp.
        Gets or sets image height. Setting this image allows to scale image vertically.

        :param height: The height of this Stamp.
        :type: float
        """

        self._height = height

    @property
    def page_index(self):
        """
        Gets the page_index of this Stamp.
        Gets or sets the index of the page.

        :return: The page_index of this Stamp.
        :rtype: int
        """
        return self._page_index

    @page_index.setter
    def page_index(self, page_index):
        """
        Sets the page_index of this Stamp.
        Gets or sets the index of the page.

        :param page_index: The page_index of this Stamp.
        :type: int
        """

        self._page_index = page_index

    @property
    def starting_number(self):
        """
        Gets the starting_number of this Stamp.
        Gets or sets value of the number of starting page. Other pages will be numbered starting from this value.

        :return: The starting_number of this Stamp.
        :rtype: int
        """
        return self._starting_number

    @starting_number.setter
    def starting_number(self, starting_number):
        """
        Sets the starting_number of this Stamp.
        Gets or sets value of the number of starting page. Other pages will be numbered starting from this value.

        :param starting_number: The starting_number of this Stamp.
        :type: int
        """

        self._starting_number = starting_number

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Stamp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from configuration import *
file_name = 'PdfWithBookmarks.pdf'
uploadFile(file_name)
opts = {
    "folder": temp_folder
}

response = pdf_api.get_document_bookmarks(file_name, **opts)

pprint(response)



from configuration import *
file_name = 'MhtExample.mht'
uploadFile(file_name)
result_name = 'fromMht.pdf'

src_path = temp_folder + '/' + file_name
opts = {
    "dst_folder": temp_folder
}
response = pdf_api.put_mht_in_storage_to_pdf(
    result_name, src_path, **opts)

pprint(response)